/*
  Copyright (c) 2006 XenSource, Inc.  All rights reserved.
*/

#ifndef XEN_VM_H
#define XEN_VM_H


#include <stdint.h>
#include <stdbool.h>

#include "xen_common.h"


/**
 * The VM class.
 *
 * A virtual machine (or 'guest')
 */


typedef char *xen_vm;


typedef struct
{
  int size;
  xen_vm *contents;
} xen_vm_set;


extern xen_vm_set
xen_vm_get_all(xen_session *s);


extern xen_vm
xen_vm_get_by_uuid(xen_session *s, char *uuid);


/**
 * VM constructor.
 */
extern xen_vm
xen_vm_create(xen_session *s, char * name_label, char * name_description,
              bool is_a_template, uint64_t memory_static_max);

/**
 * VM destructor.
 */
extern void
xen_vm_destroy(xen_session *s, xen_vm vm);

/**
 * Get the VM.uuid field: unique identifier/object reference.
 */
extern char *
xen_vm_get_uuid(xen_session *s, xen_vm vm);

extern enum xen_vm_power_state
xen_vm_get_power_state(xen_session *s, xen_vm vm);

extern char *
xen_vm_get_name_label(xen_session *s, xen_vm vm);

extern void
xen_vm_set_name_label(xen_session *s, xen_vm vm, char *label);

extern uint64_t
xen_vm_get_memory_static_max(xen_session *s, xen_vm vm);

extern xen_vm
xen_vm_clone(xen_session s, xen_vm vm, char *new_name);


#endif
